@@ -1,9 +1,8 @@
-use dataplane::derive::Encode;
-use dataplane::derive::Decode;
+use dataplane::core::{Encoder, Decoder};
 
 /// Api Key for Spu Client API (from server to client)
 #[repr(u16)]
-#[derive(PartialEq, Debug, Encode, Decode, Clone, Copy)]
+#[derive(PartialEq, Debug, Encoder, Decoder, Clone, Copy)]
 #[fluvio(encode_discriminant)]
 pub enum SpuClientApiKey {
     ReplicaOffsetUpdate = 1001,
